FlatMapError

Enum FlatMapError 

pub enum FlatMapError {
    KeyAlreadyExists,
    IsFull,
}
Failures caused by insert()

Variants



KeyAlreadyExists

The FlatMap already contains the key that shall be inserted.



IsFull

The FlatMap is full and cannot hold an additional key-value pair.