FixedSizeFlatMap

Struct FixedSizeFlatMap 

pub struct FixedSizeFlatMap<K: Eq, V: Clone, const CAPACITY: usize> { /* private fields */ }
A compile-time fixed-size, shared-memory compatible FixedSizeFlatMap.

Implementations

Source

impl<K: Eq, V: Clone, const CAPACITY: usize> FixedSizeFlatMap<K, V, CAPACITY>

pub fn new() -> Self

Creates a new FixedSizeFlatMap

pub fn insert(&mut self, id: K, value: V) -> Result<(), FlatMapError>

Inserts a new key-value pair into the FixedSizeFlatMap. On success, the method returns Ok, otherwise a FlatMapError describing the failure.

pub fn get(&self, id: &K) -> Option<V>

Returns a copy of the value corresponding to the given key. If there is no such key, None is returned.

pub fn get_ref(&self, id: &K) -> Option<&V>

Returns a reference to the value corresponding to the given key. If there is no such key, None is returned.

pub fn get_mut_ref(&mut self, id: &K) -> Option<&mut V>

Returns a mutable reference to the value corresponding to the given key. If there is no such key, None is returned.

pub fn remove(&mut self, id: &K) -> Option<V>

Removes a key (id) from the FixedSizeFlatMap, returning the Some(value) at the key if the key was previously in the map or None otherwise.

pub fn is_empty(&self) -> bool

Returns true if the FixedSizeFlatMap is empty, otherwise false.

pub fn is_full(&self) -> bool

Returns true if the FixedSizeFlatMap is full, otherwise false.

pub fn contains(&self, id: &K) -> bool

Returns true if the FixedSizeFlatMap contains the given key, otherwise false.

pub fn len(&self) -> usize

Returns the number of stored key-value pairs.

pub fn list_keys<F: FnMut(&K) -> CallbackProgression>(&self, callback: F)

Iterates over all keys of the map and calls the provided callback.