Struct FixedSizeQueue

#[repr(C)]
pub struct FixedSizeQueue<T, const CAPACITY: usize> { /* private fields */ }
Relocatable queue with compile time fixed size capacity. In contrast to its counterpart the Queue it is movable.

Implementations

Source

impl<T, const CAPACITY: usize> FixedSizeQueue<T, CAPACITY>

pub fn new() -> Self

Creates a new queue.

pub fn is_empty(&self) -> bool

Returns true if the queue is empty, otherwise false

pub fn capacity(&self) -> usize

Returns the capacity of the queue

pub fn len(&self) -> usize

Returns the number of elements inside the queue

pub fn is_full(&self) -> bool

Returns true if the queue is full, otherwise false

pub fn clear(&mut self)

Removes all elements from the queue

pub fn peek(&self) -> Option<&T>

Returns a reference to the element from the beginning of the queue without removing it. If the queue is empty it returns None.

pub fn peek_mut(&mut self) -> Option<&mut T>

Returns a mutable reference to the element from the beginning of the queue without removing it. If the queue is empty it returns None.

pub fn pop(&mut self) -> Option<T>

Removes the element from the beginning of the queue. If the queue is empty it returns None.

pub fn push(&mut self, value: T) -> bool

Adds an element at the end of the queue. If the queue is full it returns false, otherwise true.

pub fn push_with_overflow(&mut self, value: T) -> Option<T>

Adds an element at the end of the queue. If the queue is full it returns the oldest element, otherwise None.

Source

impl<T: Copy + Debug, const CAPACITY: usize> FixedSizeQueue<T, CAPACITY>

pub unsafe fn get_unchecked(&self, index: usize) -> T

Returns a copy of the element stored at index. The index is starting by 0 for the first element until FixedSizeQueue::len().

Safety
  • The index must be not out of bounds
pub fn get(&self, index: usize) -> T

Returns a copy of the element stored at index. The index is starting by 0 for the first element until FixedSizeQueue::len().