pub enum VectorModificationError {
OutOfBounds,
InsertWouldExceedCapacity,
}Expand description
Error which can occur when a Vector is modified.
Variants
OutOfBounds
An element shall be modified that is not contained in the vector.
InsertWouldExceedCapacity
The content that shall be added would exceed the maximum capacity of the
Vector.