Struct iceoryx2_bb_container::queue::FixedSizeQueue

source ·
#[repr(C)]
pub struct FixedSizeQueue<T, const CAPACITY: usize> { /* private fields */ }
Relocatable queue with compile time fixed size capacity. In contrast to its counterpart the Queue it is movable.

Implementations

source

impl<T, const CAPACITY: usize> FixedSizeQueue<T, CAPACITY>

source

pub fn new() -> Self

Creates a new queue.

source

pub fn is_empty(&self) -> bool

Returns true if the queue is empty, otherwise false

source

pub fn capacity(&self) -> usize

Returns the capacity of the queue

source

pub fn len(&self) -> usize

Returns the number of elements inside the queue

source

pub fn is_full(&self) -> bool

Returns true if the queue is full, otherwise false

source

pub fn clear(&mut self)

Removes all elements from the queue

source

pub fn pop(&mut self) -> Option<T>

Acquire an element from the queue. If the queue is empty it returns None.

source

pub fn push(&mut self, value: T) -> bool

Adds an element to the queue. If the queue is full it returns false, otherwise true.

source

pub fn push_with_overflow(&mut self, value: T) -> Option<T>

Adds an element to the queue. If the queue is full it returns the oldest element, otherwise None.

source

impl<T: Copy + Debug, const CAPACITY: usize> FixedSizeQueue<T, CAPACITY>

source

pub unsafe fn get_unchecked(&self, index: usize) -> T

Returns a copy of the element stored at index. The index is starting by 0 for the first element until FixedSizeQueue::len().

Safety
  • The index must be not out of bounds
source

pub fn get(&self, index: usize) -> T

Returns a copy of the element stored at index. The index is starting by 0 for the first element until FixedSizeQueue::len().