Struct iceoryx2_bb_container::queue::FixedSizeQueue
source · #[repr(C)]pub struct FixedSizeQueue<T, const CAPACITY: usize> { /* private fields */ }Expand description
Relocatable queue with compile time fixed size capacity. In contrast to its counterpart the
Queue it is movable.
Implementations
sourceimpl<T, const CAPACITY: usize> FixedSizeQueue<T, CAPACITY>
impl<T, const CAPACITY: usize> FixedSizeQueue<T, CAPACITY>
sourcepub fn pop(&mut self) -> Option<T>
pub fn pop(&mut self) -> Option<T>
Acquire an element from the queue. If the queue is empty it returns None.
sourcepub fn push(&mut self, value: T) -> bool
pub fn push(&mut self, value: T) -> bool
Adds an element to the queue. If the queue is full it returns false, otherwise true.
sourcepub fn push_with_overflow(&mut self, value: T) -> Option<T>
pub fn push_with_overflow(&mut self, value: T) -> Option<T>
Adds an element to the queue. If the queue is full it returns the oldest element,
otherwise None.
sourceimpl<T: Copy + Debug, const CAPACITY: usize> FixedSizeQueue<T, CAPACITY>
impl<T: Copy + Debug, const CAPACITY: usize> FixedSizeQueue<T, CAPACITY>
sourcepub unsafe fn get_unchecked(&self, index: usize) -> T
pub unsafe fn get_unchecked(&self, index: usize) -> T
Returns a copy of the element stored at index. The index is starting by 0 for the first
element until FixedSizeQueue::len().
Safety
- The index must be not out of bounds
sourcepub fn get(&self, index: usize) -> T
pub fn get(&self, index: usize) -> T
Returns a copy of the element stored at index. The index is starting by 0 for the first
element until FixedSizeQueue::len().